@@ -1,22 +1,23 @@
 #
-# $Id: String.pm,v 0.09 2004/01/06 01:40:21 sts Exp $
+# $Id: String.pm,v 0.1 2004/01/06 03:33:26 sts Exp $
 
 package Convert::ASCII::String;
 
-our $VERSION = '0.09';
+our $VERSION = '0.1';
 
 use strict 'vars';
 use warnings;
 
-use Carp;
 use Exporter;
 use base qw(Exporter);
 
 our (@EXPORT_OK, %EXPORT_TAGS, @subs);
 
 @subs = qw(string2ascii ascii2string);
+
 @EXPORT_OK = @subs;
-%EXPORT_TAGS = ( 'all' => [ @subs ] );
+%EXPORT_TAGS = (  all => [ @subs ]
+);
 
 sub SUCCESS { 1 }
 sub ARGS_MISMATCH { -1 }
